/************************************************************************
*
* Device     : RX/RX600/RX62N
*
* File Name  : extention_sample.c
*
* Abstract   : Main Program
*
* Copyright (C) 2009 Renesas Electronics Corporation.
* and Renesas Solutions Corporation. All rights reserved.
*
************************************************************************/
#include	<machine.h>                
#include	<stdbool.h>
#include	 "R_PG_sample_ext.h"

void HardwareSetup(void);
void Mtu1IcCmA_Func(void);
void S12ad0_Func(void);

#define		PSW_init  0x00010000

#define		TGRB_INIT_VAL	7500				// Interval=20ms(PCLK/64)
#define		DUTY_VAL	TGRB_INIT_VAL / 10		// Duty:10%
#define		TGRA_INIT_VAL	4687				// Interval=50ms(PCLK/256)
#define		MINIMUM_TGRA_VAL	0x200			// Interval=2.6ms(PCLK/128)

#define		DEFFAULT		0
#define		ADD_7SEG_LED	1
#define		ADD_CHG_SPD		2
#define		GPH_DSP_MOD		3

bool f_mtu2_cma, f_10ms;
unsigned char mode;
unsigned short s12ad_data;
void main(void)
{
	HardwareSetup();		// Use Hardware Setup
	set_psw(PSW_init);		// Set Ibit for PSW

	while(1){
		
		/* Judge System Mode */
		switch(mode){
			case ADD_7SEG_LED:			// 7seg LED Disp Mode
			case ADD_CHG_SPD:			// Loop Speed change Mode
				if(f_mtu2_cma){
					f_mtu2_cma = 0;
					Mtu1IcCmA_Func();	// Change Disp 7seg.LED 
				}break;
						
			case GPH_DSP_MOD:			// A/D Result Glaph Display Mode
				if(f_10ms){
					f_10ms = 0;
					S12ad0_Func();		// Disp A/D Result to 7seg.LED 
				}
		}
	}
}


// Disp Loop 7seg.LED
void Mtu1IcCmA_Func(void)
{
	static bool f_dig;
	static char loop_cnt;
	const static char seg_tbl_R[]={0xdf,0xfe,0xfd,0xfb,0xf7,0xef}; 
	const static char seg_tbl_L[]={0xfd,0xfe,0xdf,0xef,0xf7,0xfb}; 

	if(!f_dig)
		R_PG_IO_PORT_Write_PD((uint8_t)seg_tbl_R[loop_cnt]);
	else
		R_PG_IO_PORT_Write_PE((uint8_t)seg_tbl_L[loop_cnt]);
	
	if(++loop_cnt > 5){
		loop_cnt = 0;
		f_dig ^= 0x01;
	}

}

// Disp A/D Value to 7seg.LED
void S12ad0_Func(void)
{
	s12ad_data >>= 9;

	switch(s12ad_data){
		case 0:	R_PG_IO_PORT_Write_PD((uint8_t)0xf7);
				R_PG_IO_PORT_Write_PE((uint8_t)0xff);
				break;
		case 1:	R_PG_IO_PORT_Write_PD((uint8_t)0xf7);
				R_PG_IO_PORT_Write_PE((uint8_t)0xf7);
				break;
		case 2:	R_PG_IO_PORT_Write_PD((uint8_t)0xf7);
				R_PG_IO_PORT_Write_PE((uint8_t)0xe7);
				break;
		case 3:	R_PG_IO_PORT_Write_PD((uint8_t)0xf7);
				R_PG_IO_PORT_Write_PE((uint8_t)0xc7);
				break;
		case 4:	R_PG_IO_PORT_Write_PD((uint8_t)0xf7);
				R_PG_IO_PORT_Write_PE((uint8_t)0xc6);
				break;
		case 5:	R_PG_IO_PORT_Write_PD((uint8_t)0xf6);
				R_PG_IO_PORT_Write_PE((uint8_t)0xc6);
				break;
		case 6:	R_PG_IO_PORT_Write_PD((uint8_t)0xf4);
				R_PG_IO_PORT_Write_PE((uint8_t)0xc6);
				break;
		case 7:	R_PG_IO_PORT_Write_PD((uint8_t)0xf0);
				R_PG_IO_PORT_Write_PE((uint8_t)0xc6);
				
	}
}

//========================  Interrupt Function  ===============================

// MTU2 ch0 Compare Match A Interrupt
// Change PWM Pulse Duty
void Mtu0IcCmAIntFunc(void)
{
	static bool f_pwm;
	unsigned short tgra,tgrb,tgrc,tgrd,tgre,tgrf;

	/* Get TGRB Register Value */
	R_PG_Timer_GetTGR_MTU_U0_C0(&tgra,&tgrb,&tgrc,&tgrd,&tgre,&tgrf);

	/* Change PWM Duty */
	if(!f_pwm){
		if(tgrb > DUTY_VAL )		// Down Duty(Up Light)
			tgrb -= DUTY_VAL;
		else
			f_pwm = 1;
	}else{
		if(tgrb < TGRB_INIT_VAL)	// Up Duty(Down Light)
			tgrb += DUTY_VAL;
		else
			f_pwm = 0;
	}
	R_PG_Timer_SetTGR_B_MTU_U0_C0(tgrb);
	
}


// SW2 Interrupt
void Irq8IntFunc(void)
{
	R_PG_Timer_HaltCount_CMT_U0_C0();				// Stop CMT ch0
	R_PG_ADC_10_StopModule_AD0();					// 10bit A/D Module Stop 
	R_PG_ADC_12_StopModule_S12AD0();				// 12bit A/D Module Stop 
	R_PG_IO_PORT_Write_PD((uint8_t)0xff);			// 7seg.LED Off
	R_PG_IO_PORT_Write_PE((uint8_t)0xff);
	
	R_PG_Timer_SetTGR_A_MTU_U0_C1(TGRA_INIT_VAL-1);	// Reset TGRA Register Value
	R_PG_Timer_StartCount_MTU_U0_C1();				// Start MTU2 ch1
	
	mode = ADD_7SEG_LED;
}


// SW3 Interrupt
void Irq9IntFunc(void)
{
	R_PG_Timer_HaltCount_CMT_U0_C0();			// Stop CMT ch0
	R_PG_ADC_12_StopModule_S12AD0();			// 12bit A/D Module Stop
	R_PG_IO_PORT_Write_PD((uint8_t)0xff);		// 7seg.LED Off
	R_PG_IO_PORT_Write_PE((uint8_t)0xff);

	R_PG_ADC_10_Set_AD0();						// Initial 10bit A/D
	R_PG_ADC_10_StartConversionSW_AD0();		// Start 10it A/D
	R_PG_Timer_StartCount_MTU_U0_C1();			// Start MTU2 ch1

	mode = ADD_CHG_SPD;
}

// SW4 Interrupt
void Irq10IntFunc(void)
{
	R_PG_ADC_10_StopModule_AD0();				// 10bit A/D Module Stop 
	R_PG_Timer_HaltCount_MTU_U0_C1();			// Stop MTU2 ch1
		
	R_PG_ADC_12_Set_S12AD0();					// Initial 12bit A/D
	R_PG_ADC_12_StartConversionSW_S12AD0();		// Start 12bit A/D
	R_PG_Timer_ResumeCount_CMT_U0_C0();			// Start CMT(interval:10ms)

	mode = GPH_DSP_MOD;
}

// MTU2 ch1 Compare Match A Interrupt
void Mtu1IcCmAIntFunc(void)
{
	f_mtu2_cma = 1;
	
}

// 10bit A/D Interrupt
void Ad0IntFunc(void)
{
	 unsigned short ad_data;
	 
	 R_PG_ADC_10_GetResult_AD0(&ad_data);		// Get 10bitA/D Result
	 
	// Set A/D Value to MTU2 TGRA Register
	ad_data *= 8;
	if(ad_data < 0x400)
		R_PG_Timer_SetTGR_A_MTU_U0_C1(MINIMUM_TGRA_VAL);
	else
		R_PG_Timer_SetTGR_A_MTU_U0_C1(ad_data);
	
}

// CMT Interrupt
void Cmt0IntFunc(void)
{
	f_10ms = 1;

	R_PG_ADC_12_GetResult_S12AD0(&s12ad_data);	// Get 12bitA/D Result
	
}
